Learn R Programming

canaper (version 1.0.1)

cpr_signif_cols_2: CVD-friendly color palette for plotting results of randomization test, version 2

Description

Character vector with names corresponding to significance levels and values corresponding to color codes, with "not significant" colored grey.

Usage

cpr_signif_cols_2

Arguments

Format

An object of class character of length 5.

See Also

Other colors: cpr_endem_cols_2, cpr_endem_cols_3, cpr_endem_cols_4, cpr_endem_cols, cpr_make_pal(), cpr_signif_cols, mishler_endem_cols, mishler_signif_cols

Examples

Run this code
cpr_signif_cols_2
scales::show_col(cpr_signif_cols_2)

Run the code above in your browser using DataLab