Learn R Programming

canaper (version 1.0.1)

mishler_endem_cols: Original color palette for plotting results of CANAPE

Description

Character vector with names corresponding to endemism types and values corresponding to color codes. Original palette used by Mishler et al. (2014). May not be distinguishable to people with color vision deficiency (CVD).

Usage

mishler_endem_cols

Arguments

Format

An object of class character of length 5.

Details

Color scheme:

  • paleo: blue

  • neo: red

  • not significant: beige

  • mixed: light purple

  • super: dark purple

References

Mishler, B., Knerr, N., González-Orozco, C. et al. (2014) Phylogenetic measures of biodiversity and neo- and paleo-endemism in Australian Acacia. Nat Commun, 5: 4473. tools:::Rd_expr_doi("10.1038/ncomms5473")

See Also

Other colors: cpr_endem_cols_2, cpr_endem_cols_3, cpr_endem_cols_4, cpr_endem_cols, cpr_make_pal(), cpr_signif_cols_2, cpr_signif_cols, mishler_signif_cols

Examples

Run this code
mishler_endem_cols
scales::show_col(mishler_endem_cols)

Run the code above in your browser using DataLab