Learn R Programming

canaper (version 1.0.1)

acacia: Acacia example data

Description

Dataset of Australian Acacia from Mishler et al. 2014 (Nat. Comm.)

Usage

acacia

Arguments

Format

A list with two elements:

phy

Phylogeny of Australian Acacia (list of class "phylo"). Tip labels are specific epithet, except for the outgroup, which includes genus and specific epithet. Includes 508 ingroup taxa (genus Acacia) and two outgroup taxa.

comm

Community matrix of Australian Acacia (dataframe). Column names are specific epithet of each species. Row names are centroids of 50km grid cells in Australian Albers equal area EPSG:3577 projection. 3037 rows (sites) x 506 columns (species). Data are counts, i.e., the number of times a species was observed in a grid cell.

References

Mishler, B., Knerr, N., González-Orozco, C. et al. Phylogenetic measures of biodiversity and neo- and paleo-endemism in Australian Acacia. Nat Commun 5, 4473 (2014). tools:::Rd_expr_doi("10.1038/ncomms5473")

Examples

Run this code
# Example phylogeny
acacia$phy
# Example community
acacia$comm[1:5, 1:5]

Run the code above in your browser using DataLab